@@ -2,15 +2,15 @@
 from typing import Any, List, Optional
 
 from eventbus.domain.aggregate import BaseAggregateRoot
-from eventbus.domain.entity import TimestampedEntity
+from eventbus.domain.entity import TimestampedVersionedEntity
 
 
-class ExampleInternal(TimestampedEntity):
+class ExampleInternal(TimestampedVersionedEntity):
     def __init__(self, value: int, **kwargs: Any):
         super().__init__(**kwargs)
         self.value = value
 
-    class Event(TimestampedEntity.Event):
+    class Event(TimestampedVersionedEntity.Event):
         pass
 
 
@@ -43,5 +43,5 @@ class Example(BaseAggregateRoot):
             obj.internals.append(self.internal)
 
     async def add(self, value: int):
-        internal = await ExampleInternal.__create__(event_bus=self.event_bus, value=value)
+        internal = await ExampleInternal.__create__(value=value)
         await self.__trigger_event__(Example.ExampleInternalAdded, internal=internal)
