@@ -6,12 +6,13 @@ from uuid import uuid4
 
 import pytest
 
-from eventbus.application.eventbus import EventBus
+from eventbus.application.eventbus import subscribe
 from eventbus.domain.eventbus import AbstractEventHandler
 from eventbus.domain.events import DomainEvent
 from eventbus.domain.exceptions import EntityIsDiscarded, OriginatorVersionError, OriginatorIDError
 from eventbus.domain.whitehead import TEvent
-from eventbus.example.entity import Example, ExampleInternal
+from eventbus.example.entity import Example
+from eventbus.util.topic import get_entity
 
 
 @pytest.mark.asyncio
@@ -40,23 +41,27 @@ async def test_example_entity():
     handler1 = AllEventsTestHandler()
     handler2 = NonExistentEventsTestHandler()
 
-    bus = EventBus(handlers=[
-        handler1, handler2
-    ])
-
     # Same instance of handler will be skipped
-    bus.subscribe(handler1)
+    subscribe(handler1)
     # No such events thus skipping as well
-    bus.subscribe(handler2)
+    subscribe(handler2)
 
-    # "Example.Created" has been added to a pending list (Domain Root Entity)
-    example = await Example.__create__(event_bus=bus, first_name="First", last_name="Last", age=56)
+    example = await Example.__create__(first_name="First", last_name="Last", age=56)
     assert example.__version__ == 0
 
     # All dates are in default state
     assert example.__created_on__ == example.__updated_on__ == example.__last_modified__
 
+    # "Example.Created" has been added to a pending list (Domain Root Entity)
     assert len(example.__pending_events__) == 1
+
+    # Trying to revive entity from created event
+    event = example.__pending_events__.popleft()
+    revived_example = get_entity(event)
+    assert example == revived_example
+    # Restore
+    example.__pending_events__.append(event)
+
     assert len(received_events) == 0
 
     for value in [10, 20, 30]:
@@ -103,7 +108,6 @@ async def test_example_entity():
     now = datetime.now(tz=timezone.utc)
     another_example = Example(
         id=uuid4(),
-        event_bus=bus,
         first_name="First #2",
         last_name="Last #2",
         age=56,
@@ -119,7 +123,6 @@ async def test_example_entity():
 
     # Create entity with discarted state
     another_example = await Example.__create__(
-        event_bus=bus,
         first_name="First #2",
         last_name="Last #2",
         age=56,
